@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
 RSpec.describe Licensee::License do
-  let(:license_count) { 41 }
-  let(:hidden_license_count) { 28 }
+  let(:license_count) { 43 }
+  let(:hidden_license_count) { 30 }
   let(:featured_license_count) { 3 }
   let(:pseudo_license_count) { 2 }
   let(:non_featured_license_count) do
@@ -300,7 +300,7 @@ RSpec.describe Licensee::License do
   end
 
   it 'knows equality' do
-    expect(mit).to eql(mit)
+    expect(described_class.find('mit')).to eql(mit)
     expect(gpl).not_to eql(mit)
   end
 
@@ -383,7 +383,7 @@ RSpec.describe Licensee::License do
               expect(described_class.find_by_title(text)).to eql(license)
             end
 
-            if license.title =~ /\bGNU\b/
+            if /\bGNU\b/.match?(license.title)
               context "without 'GNU'" do
                 let(:text) { license_variation.sub(/GNU /i, '') }
 
@@ -490,7 +490,7 @@ RSpec.describe Licensee::License do
             prefixes.each do |prefix|
               context "with '#{prefix}' before the host" do
                 before do
-                  source.host = "#{prefix}#{source.host.sub(/\Awww\./, '')}"
+                  source.host = "#{prefix}#{source.host.delete_prefix('www.')}"
                 end
 
                 suffixes.each do |suffix|
@@ -498,7 +498,7 @@ RSpec.describe Licensee::License do
                     before do
                       next if license.key == 'wtfpl'
 
-                      regex = /#{Licensee::License::SOURCE_SUFFIX}\z/
+                      regex = /#{Licensee::License::SOURCE_SUFFIX}\z/o
                       source.path = source.path.sub(regex, '')
                       source.path = "#{source.path}#{suffix}"
                     end
