@@ -1,10 +1,13 @@
+# frozen_string_literal: true
+
 RSpec.describe Licensee::Matchers::Cran do
+  subject { described_class.new(file) }
+
   let(:mit) { Licensee::License.find('mit') }
   let(:gpl2) { Licensee::License.find('gpl-2.0') }
   let(:gpl3) { Licensee::License.find('gpl-3.0') }
   let(:content) { "License: MIT + file LICENSE\nPackage: test" }
-  let(:file) { Licensee::Project::LicenseFile.new(content, 'DESCRIPTION') }
-  subject { described_class.new(file) }
+  let(:file) { Licensee::ProjectFiles::LicenseFile.new(content, 'DESCRIPTION') }
 
   it 'stores the file' do
     expect(subject.file).to eql(file)
@@ -15,7 +18,7 @@ RSpec.describe Licensee::Matchers::Cran do
   end
 
   it 'is confident' do
-    expect(subject.confidence).to eql(90)
+    expect(subject.confidence).to be(90)
   end
 
   {
@@ -26,7 +29,8 @@ RSpec.describe Licensee::Matchers::Cran do
     'GPL (>=2) + file LICENSE' => Licensee::License.find('gpl-2.0'),
     'GPL (>=3)'                => Licensee::License.find('gpl-3.0'),
     'GPL-2'                    => Licensee::License.find('gpl-2.0'),
-    'GPL-3'                    => Licensee::License.find('gpl-3.0')
+    'GPL-3'                    => Licensee::License.find('gpl-3.0'),
+    'Foo'                      => Licensee::License.find('other')
   }.each do |license_declaration, license|
     context "with '#{license_declaration}' declaration" do
       let(:content) { "Package: test\nLicense: #{license_declaration}" }
@@ -36,4 +40,12 @@ RSpec.describe Licensee::Matchers::Cran do
       end
     end
   end
+
+  context 'with no license field' do
+    let(:content) { 'Package: test' }
+
+    it 'returns nil' do
+      expect(subject.match).to be_nil
+    end
+  end
 end
