@@ -22,12 +22,12 @@ RSpec.describe Licensee::Matchers::Dice do
 
   it 'sorts licenses by similarity' do
     expect(subject.matches_by_similarity[0]).to eql([gpl, 100.0])
-    expect(subject.matches_by_similarity[1]).to eql([agpl, 95.28301886792453])
-    expect(subject.matches_by_similarity[2]).to eql([lgpl, 39.33253873659118])
+    expect(subject.matches_by_similarity[1]).to eql([agpl, 94.56967213114754])
+    expect(subject.matches_by_similarity[2]).to eql([lgpl, 26.821370750134918])
   end
 
   it 'returns the match confidence' do
-    expect(subject.confidence).to be(100.0)
+    expect(subject.confidence).to eq(100.0)
   end
 
   context 'without a match' do
