@@ -66,7 +66,7 @@
         let(:revision) { subject.repository.last_commit.oid }
 
         before do
-          subject.instance_variable_set('@revision', revision)
+          subject.instance_variable_set(:@revision, revision)
         end
 
         it 'returns the commit' do
@@ -106,9 +106,7 @@
         license = files.find { |f| f[:name] == 'LICENSE.txt' }
         expect(license).not_to be_nil
 
-        if described_class == Licensee::Projects::GitProject
-          expect(files.first).to have_key(:oid)
-        end
+        expect(files.first).to have_key(:oid) if described_class == Licensee::Projects::GitProject
       end
 
       it "returns a file's content" do
@@ -118,11 +116,12 @@
 
       if described_class == Licensee::Projects::FSProject
         context 'with search root argument' do
+          subject { described_class.new(path, search_root: search_root) }
+
           let(:fixture) { 'license-in-parent-folder/license-folder/package' }
           let(:path) { fixture_path(fixture) }
           let(:license_folder) { 'license-in-parent-folder/license-folder' }
           let(:search_root) { fixture_path(license_folder) }
-          let(:subject) { described_class.new(path, search_root: search_root) }
           let(:files) { subject.send(:files) }
 
           it 'looks for licenses in parent directories up to the search root' do
