@@ -80,8 +80,8 @@ end
 
 # Add random words to the end of a license to test similarity tollerances
 def add_random_words(string, count = 5)
-  words = string.dup.split(' ')
-  ipsum = File.read(fixture_path('ipsum.txt')).split(' ')
+  words = string.dup.split
+  ipsum = File.read(fixture_path('ipsum.txt')).split
   count.times do
     word = ipsum[Random.rand(ipsum.length)]
     index = Random.rand(words.length)
@@ -91,7 +91,7 @@ def add_random_words(string, count = 5)
 end
 
 # Init git dir
-# Note: we disable gpgsign and restore it to its original setting to avoid
+# NOTE: we disable gpgsign and restore it to its original setting to avoid
 # Signing commits during tests and slowing down / breaking specs
 def git_init(path)
   Dir.chdir path do
